Examples
--------

See `/comparisons` for the code to generate the graphs below.

The graph below shows intrinsic rates of H/D exchange calculated with exPfact / PSX (PSX: 'poly' and 'oligo').
The overall trend in exchange rates is similar but there is an constant 1.8-2.5 fold difference between different methods,
with outliers up to ~10-fold.

.. raw:: html

    <img src="comparisons/Rate differences.png" width="800" />

The histograms show fold-difference between exPfact and PSX (poly) for different pH values (T=300K). Differences range
from 1.6-fold to 40-fold.


.. raw:: html

    <img src="comparisons/Rate differences histograms.png" width="800" />